==> jquery-countto-1.2.2.tgz: jquery-countto/README.md <==
# Installation
> `npm install --save @types/jquery-countto`

# Summary
This package contains type definitions for JQuery CountTo (https://github.com/mhuggins/jquery-countTo).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-countto.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-countto/index.d.ts)
````ts
// Type definitions for JQuery CountTo 1.2
// Project: https://github.com/mhuggins/jquery-countTo
// Definitions by: Anderson Friaça <https://github.com/AndersonFriaca>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

export type Options = Partial<{
    /**
     * The number to start counting from
     */
    from: number;

    /**
     * The number to stop counting at
     */
    to: number;

    /**
     * The number of milliseconds it should take to finish counting
     */
    speed: number;

    /**
     * The number of milliseconds to wait between refreshing the counter
     */
    refreshInterval: number;

    /**
     * The number of decimal places to show when using the default formatter
     */
    decimals: number;

    /**
     * A handler that is used to format the current value before rendering to the DOM
     */
    formatter: (value: number, options: Options) => string;

    /**
     * A callback function that is triggered for every iteration that the counter updates
     */
    onUpdate: (value: number) => void;

    /**
     * A callback function that is triggered when counting finishes
     */
    onComplete: (value: number) => void;
}>;

export type Method = "start" | "stop" | "toggle" | "restart";

declare global {
    interface JQuery {
        countTo(methodOrOptions?: Method | Options): JQuery;
    }
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).

==> jquery-countto-1.2.3.tgz: jquery-countto/README.md <==
# Installation
> `npm install --save @types/jquery-countto`

# Summary
This package contains type definitions for jquery-countto (https://github.com/mhuggins/jquery-countTo).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-countto.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-countto/index.d.ts)
````ts
/// <reference types="jquery" />

export type Options = Partial<{
    /**
     * The number to start counting from
     */
    from: number;

    /**
     * The number to stop counting at
     */
    to: number;

    /**
     * The number of milliseconds it should take to finish counting
     */
    speed: number;

    /**
     * The number of milliseconds to wait between refreshing the counter
     */
    refreshInterval: number;

    /**
     * The number of decimal places to show when using the default formatter
     */
    decimals: number;

    /**
     * A handler that is used to format the current value before rendering to the DOM
     */
    formatter: (value: number, options: Options) => string;

    /**
     * A callback function that is triggered for every iteration that the counter updates
     */
    onUpdate: (value: number) => void;

    /**
     * A callback function that is triggered when counting finishes
     */
    onComplete: (value: number) => void;
}>;

export type Method = "start" | "stop" | "toggle" | "restart";

declare global {
    interface JQuery {
        countTo(methodOrOptions?: Method | Options): JQuery;
    }
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 05:47:07 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).
